@@ -10,6 +10,7 @@ from contextvars import ContextVar
 from typing import Dict, List, Optional, Union, Type
 
 import aiohttp
+import certifi
 from aiohttp.helpers import sentinel
 
 from . import api
@@ -79,7 +80,7 @@ class BaseBot:
         self.proxy_auth = proxy_auth
 
         # aiohttp main session
-        ssl_context = ssl.create_default_context(cafile="/etc/ssl/certs/ca-certificates.crt")
+        ssl_context = ssl.create_default_context(cafile=certifi.where())
 
         self._session: Optional[aiohttp.ClientSession] = None
         self._connector_class: Type[aiohttp.TCPConnector] = aiohttp.TCPConnector
